@@ -539,7 +539,9 @@ on_legacy_async_callback (GObject *source, GAsyncResult *res, gpointer user_data
             !g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
                 if (error != NULL)
                         g_propagate_error (&action->error, error);
-                action->callback (action->proxy, action, action->user_data);
+                // action's proxy will be NULL now due to call_action_finish. So
+                // we use the one from our callback
+                action->callback (GUPNP_SERVICE_PROXY (source), action, action->user_data);
         }
 
         g_clear_error (&error);
@@ -746,18 +748,18 @@ action_task_got_response (SoupSession *session,
                 action->cancellable_connection_id = 0;
         }
 
-        if (SOUP_STATUS_IS_TRANSPORT_ERROR (msg->status_code)) {
-                g_task_return_new_error (
-                        task,
-                        GUPNP_SERVER_ERROR,
-                        GUPNP_SERVER_ERROR_OTHER,
-                        "Server does not allow any POST messages");
-        } else if (msg->status_code == SOUP_STATUS_CANCELLED) {
+        if (msg->status_code == SOUP_STATUS_CANCELLED) {
                 g_task_return_new_error (task,
                                          G_IO_ERROR,
                                          G_IO_ERROR_CANCELLED,
                                          "Action message was cancelled");
-        } else {
+        } else if (SOUP_STATUS_IS_TRANSPORT_ERROR (msg->status_code)) {
+                g_task_return_new_error (task,
+                                         GUPNP_SERVER_ERROR,
+                                         GUPNP_SERVER_ERROR_OTHER,
+                                         "%s",
+                                         msg->reason_phrase);
+        } else  {
                 g_task_return_pointer (task,
                                        g_task_get_task_data (task),
                                        NULL);
