@@ -6,20 +6,8 @@
  *         Zeeshan Ali (Khattak) <zeeshanak@gnome.org>
  *                               <zeeshan.ali@nokia.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
 /**
@@ -45,13 +33,12 @@
  */
 struct _GUPnPXMLDoc {
         GObject parent;
-        /*< public >*/
         xmlDoc *doc;
 };
 
 G_DEFINE_TYPE (GUPnPXMLDoc,
                gupnp_xml_doc,
-               G_TYPE_OBJECT);
+               G_TYPE_OBJECT)
 
 static void
 gupnp_xml_doc_init (G_GNUC_UNUSED GUPnPXMLDoc *doc)
@@ -66,7 +53,7 @@ gupnp_xml_doc_finalize (GObject *object)
 
         doc = GUPNP_XML_DOC (object);
 
-        xmlFreeDoc (doc->doc);
+        g_clear_pointer (&doc->doc, xmlFreeDoc);
 
         G_OBJECT_CLASS (gupnp_xml_doc_parent_class)->finalize (object);
 }
@@ -83,13 +70,13 @@ gupnp_xml_doc_class_init (GUPnPXMLDocClass *klass)
 
 /**
  * gupnp_xml_doc_new:
- * @xml_doc: Pointer to #xmlDoc to wrap under this object
+ * @xml_doc:(transfer full): Pointer to #xmlDoc to wrap under this object
  *
  * Create a new #GUPnPXMLDoc for @xml_doc.
  *
  * Return value: A new #GUPnPXMLDoc, or %NULL on an error
  *
- * Since: 0.13.0
+ * Since: 0.14.0
  **/
 GUPnPXMLDoc *
 gupnp_xml_doc_new (xmlDoc *xml_doc)
@@ -108,13 +95,13 @@ gupnp_xml_doc_new (xmlDoc *xml_doc)
 /**
  * gupnp_xml_doc_new_from_path:
  * @path: Path to xml document
- * @error: Location to put the error into
+ * @error:(inout)(optional)(nullable): Location to put the error into
  *
  * Create a new #GUPnPXMLDoc for the XML document at @path.
  *
- * Return value: A new #GUPnPXMLDoc, or %NULL on an error
+ * Return value:(nullable): A new #GUPnPXMLDoc, or %NULL on an error
  *
- * Since: 0.13.0
+ * Since: 0.14.0
  **/
 GUPnPXMLDoc *
 gupnp_xml_doc_new_from_path (const char *path,
